.. _jobs:

Jobs
====
LSTOSA job creation and submission using `SLURM`_. There are several functions to handle the job processing levels
keeping the history of all the different steps.

.. _`SLURM`: https://slurm.schedmd.com/

Reference/API
-------------

.. automodule:: osa.job
   :members:

